function [] = plot_isochrones(a,b,alpha)
% Plots an isochrone for positive offset
% 
% Input:
% a, b      parameter of sound speed $v(\mathbf(x))=b+a*x_2$
% alpha     offset (2*alpha is the distance of source and receiver)
%
% Output:
% Plot of the isochrone with respect to the sound speed 
% determined by a and b
%
% Version: June 1, 2021

if nargin<3
    a=0.6; b=0.5;alpha=5;
    disp(' ');
    disp('Too few input arguments!');
    disp('=> Default values a=0.6, b=0.5, alpha=5 used.');
    disp(' ');
end

o=alpha;
tmin1 = 2*asinh(a*o/b)/a;
tmin2 = 4*asinh(a*o/b/2)/a;

if a<=0 || b<=0 || o<=0
    error('Error! All input variables must be positive.');
end
    
prompt = ['Enter travel time (t>' num2str(tmin1),'): '];
t=input(prompt);

if isempty(t)||(t<tmin1)
    t=1.1*tmin1;
    disp(' ');
    disp(['=> Default value t=1.1*' num2str(tmin1),' used.']);
end


c2=@(a,b,t,d)b*(cosh(a*(t-d))-1)/a;
c1=@(a,b,t,d)b*(cosh(a*d)-1)/a;

s=@(a,b,t,d,o)4*a^2*o^2*(c1(a,b,t,d).*c2(a,b,t,d)-o^2)+4*a*b*o^2*(c1(a,b,t,d)+c2(a,b,t,d))-b^2*(c1(a,b,t,d)-c2(a,b,t,d)).^2;
dx_plus=@(a,b,t,d,o)(sqrt(s(a,b,t,d,o))+o*(2*b+a*(c1(a,b,t,d)+c2(a,b,t,d))))./((c1(a,b,t,d)-c2(a,b,t,d)).^2+4*o^2)/a;
dx_minus=@(a,b,t,d,o)(-sqrt(s(a,b,t,d,o))+o*(2*b+a*(c1(a,b,t,d)+c2(a,b,t,d))))./((c1(a,b,t,d)-c2(a,b,t,d)).^2+4*o^2)/a;

 n=max(1000,10*ceil(t^2));
    i=linspace(0,2*n,2*n+1);
    dd=t/2-(tmin1/2)* cos(pi*(2*i+1)./(4*n+2));
    d=[dd(n+1:2*n+1)-tmin1/2 dd(1:n)+tmin1/2];

if t<tmin2    
    delta_plus=real(dx_plus(a,b,t,d,o)); 
    delta_minus=real(dx_minus(a,b,t,d,o)); 

    x_plus=(c1(a,b,t,d)-c2(a,b,t,d)).*delta_plus;
    x_minus=(c1(a,b,t,d)-c2(a,b,t,d)).*delta_minus;

    y_plus=b/a-2*o*delta_plus;
    y_minus=b/a-2*o*delta_minus;

    clf;ax=gca;
    plot(x_plus,y_plus,'LineWidth',3,'Color','black');
    set(gca,'FontSize',16);  axis equal; axis tight;
    title(['Isochrone for $v(\mathbf{x}) =\ $' num2str(a) '$x_2+$' num2str(b), ...
        ' for $\alpha=\ $' num2str(o), ', $t=\ $' num2str(t)],'Interpreter','latex','FontSize',18);
    xlabel(['$x_1$'],'Interpreter','latex','FontSize',18);
    ylabel(['$x_2$'],'Interpreter','latex','FontSize',18);
    hold on;
    plot(x_minus,y_minus,'LineWidth',3,'Color','black');
    ax.YLim=[min(y_plus) 0.];
    ax.YTickLabel=abs(ax.YTick);
    plot(-o,0,'o','MarkerSize',10,'MarkerEdgeColor','red','MarkerFaceColor','red');
    plot(o,0,'o','MarkerSize',10,'MarkerEdgeColor','red','MarkerFaceColor','red'); 
else
    delta_plus=real(dx_plus(a,b,t,d,o)); 
    
    x_plus=(c1(a,b,t,d)-c2(a,b,t,d)).*delta_plus;
    y_plus=b/a-2*o*delta_plus;
  
    clf;ax=gca;
    plot(x_plus,y_plus,'LineWidth',3,'Color','black');
    set(gca,'FontSize',16);  axis equal;
    title(['Isochrone for $v(\mathbf{x}) =\ $' num2str(a) '$x_2+$' num2str(b), ...
        ' for $\alpha=\ $' num2str(o), ', $t=\ $' num2str(t)],'Interpreter','latex','FontSize',18);
    xlabel(['$x_1$'],'Interpreter','latex','FontSize',18);
    ylabel(['$x_2$'],'Interpreter','latex','FontSize',18);
    ax.YLim=[ax.YLim(1) 0];
    ax.YTickLabel=abs(ax.YTick);
    hold on;
    plot(-o,0,'o','MarkerSize',10,'MarkerEdgeColor','red','MarkerFaceColor','red');
    plot(o,0,'o','MarkerSize',10,'MarkerEdgeColor','red','MarkerFaceColor','red'); 

end