
function [] = plot_partial_s_phi3(a,b,alpha)
% Plots the function $\partial_s\varphi(0,\mathbf{x}^+(.))$
% 
% Input:
% a, b      parameter of sound speed $v(\mathbf(x))=b+a*x_2$
% alpha     offset (2*alpha is the distance of source and receiver)
%
% Output:
% Plot of the above function for values $\vartheta$ for which
% $x_2^(\vartheta)>=x_min$ holds true.
%
% Version: August 20, 2021

dim=1000; 

R=@(a,b,t)2*b*sinh(a*t/2)/a;
T=@(a,b,t)2*b*cosh(a*t/2)/a;


D=@(a,b,o,t,e)2*o*(2*o*cosh(a*t/2)*cosh(a*e)+sqrt(R(a,b,t)^2-4*o^2)*sqrt(1+a^2*o^2/b^2-cosh(a*e).^2))./...
   (R(a,b,t)^2*sinh(a*e).^2+4*o^2);

if nargin<3
    a=1; b=1;alpha=1;
    disp(' ');
    disp('Too few input arguments!');
    disp('=> Default values a=b=alpha=1 used.');
    disp(' ');
end

o=alpha;
tmin = 2*asinh(a*o/b)/a;

if a<=0 || b<=0 || o<=0
    error('Error! All input variables must be positive.');
end
    
prompt = ['Enter travel time (t>' num2str(tmin),'): '];
t=input(prompt);

if isempty(t)||(t<=tmin)
    t=1.1*tmin;
    disp(' ');
    disp(['=> Default value t=1.1*' num2str(tmin),' used.']);
end

syms ee
digits(16);

%Solving the equation for $\varepsilon_{*,2}$ 
 e2=abs(real(double(vpasolve(D(a,b,o,t,ee)==sqrt(1+a^2*o^2/b^2),ee,0.45*tmin))));
 
if (isempty(e2)||e2==0)
    error('Numerical instabilities. Use a differnet travel time.');
end

e=linspace(0,tmin/2,dim);
TT=T(a,b,t);
RR=R(a,b,t);

% z=\partial_s varphi(0,x^+(.))
z = (4/a/o)*sinh(a*e)./((1-TT^2/RR^2)*sinh(a*e).^2+1).* ...
    (TT*a*o*(RR^2-4*o^2)+b*RR^2*cosh(a*e).*sqrt(RR^2-4*o^2).*sqrt(cosh(a*tmin/2)^2-cosh(a*e).^2))./...
    (a*o*TT*RR^2*cosh(a*e)+RR^2*b*sqrt(RR^2-4*o^2)*sqrt(cosh(a*tmin/2)^2-cosh(a*e).^2));

fig1=figure(1);clf; 
    
set(fig1,'pos',[400 558 1000 420]);
subplot(1,2,1)
plot(e+t/2,z,'LineWidth',3);
hold on;
plot([t/2 e2+t/2],[0 0],'LineWidth',4,'Color','red');
set(gca,'FontSize',16);
title(['$\partial_s\varphi(0,\mathbf{x}^+(\cdot))$ for $a=$' num2str(a), ', $b=$' num2str(b), ...
    ', $\alpha=$' num2str(o), ', $t=$' num2str(t)],'Interpreter','latex','FontSize',18);
xlabel(['$\vartheta_{\max,2}=$' num2str(e2+t/2)],'Interpreter','latex','FontSize',18);
axis tight;
hold off;

% Zoom plot
clear e z;
dim=100;
e=linspace(0,e2,dim);

z = (4/a/o)*sinh(a*e)./((1-TT^2/RR^2)*sinh(a*e).^2+1).* ...
    (TT*a*o*(RR^2-4*o^2)+b*RR^2*cosh(a*e).*sqrt(RR^2-4*o^2).*sqrt(cosh(a*tmin/2)^2-cosh(a*e).^2))./...
    (a*o*TT*RR^2*cosh(a*e)+RR^2*b*sqrt(RR^2-4*o^2)*sqrt(cosh(a*tmin/2)^2-cosh(a*e).^2));

subplot(1,2,2)
plot(e+t/2,z,'LineWidth',3);
set(gca,'FontSize',16);
title('$\partial_s\varphi(0,\mathbf{x}^+(\cdot))$ from the left zoomed in on $[t/2,\vartheta_{\max,2}]$', ...
      'Interpreter','latex','FontSize',18);
axis tight;
end